==> gromp-0.8.0-py3-none-any.whl: gromp/endpoint/league/__init__.py <==
"""
MIT License

Copyright (c) 2023 Wilhelm Ågren

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

File created: 2023-02-05
Last updated: 2023-02-14
"""

from .ChampionMasteryv4 import ChampionMasteryv4
from .Championv3 import Championv3
from .Clashv1 import Clashv1
from .LeagueExpv4 import LeagueExpv4
from .LolChallengesv1 import LolChallengesv1
from .Leaguev4 import Leaguev4
from .LolStatusv4 import LolStatusv4
from .Matchv5 import Matchv5
from .Spectatorv4 import Spectatorv4
from .Summonerv4 import Summonerv4
from .TournamentStubv4 import TournamentStubv4
from .Tournamentv4 import Tournamentv4

==> gromp-1.0.0-py3-none-any.whl: gromp/endpoint/league/__init__.py <==
"""
MIT License

Copyright (c) 2023 Wilhelm Ågren

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

File created: 2023-02-05
Last updated: 2023-11-04
"""

from .ChampionMasteryv4 import ChampionMasteryv4  # noqa
from .Championv3 import Championv3  # noqa
from .Clashv1 import Clashv1  # noqa
from .LeagueExpv4 import LeagueExpv4  # noqa
from .LolChallengesv1 import LolChallengesv1  # noqa
from .Leaguev4 import Leaguev4  # noqa
from .LolStatusv4 import LolStatusv4  # noqa
from .Matchv5 import Matchv5  # noqa
from .Spectatorv4 import Spectatorv4  # noqa
from .Summonerv4 import Summonerv4  # noqa
from .TournamentStubv4 import TournamentStubv4  # noqa
from .Tournamentv4 import Tournamentv4  # noqa
